==> boombox-2.0.2-www.persianscript.ir.zip: boombox/amp/fonts/icomoon/style.php <==
<?php
// Root url
$root_url = get_template_directory_uri() . '/amp/';
$icon_fonts_url = $root_url.'fonts/icomoon/fonts/';
?>

@font-face {
  font-family: 'icomoon';
  src:  url('<?php echo $icon_fonts_url;?>icomoon.eot?3ezurc');
  src:  url('<?php echo $icon_fonts_url;?>icomoon.eot?3ezurc#iefix') format('embedded-opentype'),
    url('<?php echo $icon_fonts_url;?>icomoon.ttf?3ezurc') format('truetype'),
    url('<?php echo $icon_fonts_url;?>icomoon.woff?3ezurc') format('woff'),
    url('<?php echo $icon_fonts_url;?>icomoon.svg?3ezurc#icomoon') format('svg');
  font-weight: normal;
  font-style: normal;
}

[class^="icon-"], [class*=" icon-"] {
  font-family: 'icomoon';
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
   -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

.icon-soundcloud:before {
  content: "\f1be";
}
.icon-mixcloud:before {
  content: "\f289";
}
.icon-quora:before {
  content: "\f2c4";
}
.icon-chevron-left:before {
  content: "\f053";
}
.icon-chevron-right:before {
  content: "\f054";
}
.icon-comment-o:before {
  content: "\f0e5";
}
.icon-snapchat:before {
  content: "\f2ab";
}
.icon-snapchat-square:before {
  content: "\f2ad";
}
.icon-globe:before {
  content: "\f0ac";
}
.icon-quote-left:before {
  content: "\f10d";
}
.icon-telegram:before {
  content: "\f2c6";
}
.icon-close:before {
  content: "\f00d";
}
.icon-share:before {
  content: "\f064";
}
.icon-comment:before {
  content: "\f075";
}
.icon-twitter:before {
  content: "\f099";
}
.icon-facebook:before {
  content: "\f09a";
}
.icon-github:before {
  content: "\f09b";
}
.icon-pinterest:before {
  content: "\f0d2";
}
.icon-google-plus:before {
  content: "\f0d5";
}
.icon-caret-down:before {
  content: "\f0d7";
}
.icon-caret-up:before {
  content: "\f0d8";
}
.icon-envelope:before {
  content: "\f0e0";
}
.icon-linkedin:before {
  content: "\f0e1";
}
.icon-youtube:before {
  content: "\f167";
}
.icon-xing:before {
  content: "\f168";
}
.icon-stack-overflow:before {
  content: "\f16c";
}
.icon-instagram:before {
  content: "\f16d";
}
.icon-flickr:before {
  content: "\f16e";
}
.icon-tumblr:before {
  content: "\f173";
}
.icon-dribbble:before {
  content: "\f17d";
}
.icon-foursquare:before {
  content: "\f180";
}
.icon-vk:before {
  content: "\f189";
}
.icon-reddit:before {
  content: "\f1a1";
}
.icon-stumbleupon:before {
  content: "\f1a4";
}
.icon-delicious:before {
  content: "\f1a5";
}
.icon-digg:before {
  content: "\f1a6";
}
.icon-behance:before {
  content: "\f1b4";
}
.icon-deviantart:before {
  content: "\f1bd";
}
.icon-vine:before {
  content: "\f1ca";
}
.icon-codepen:before {
  content: "\f1cb";
}
.icon-jsfiddle:before {
  content: "\f1cc";
}
.icon-slideshare:before {
  content: "\f1e7";
}
.icon-twitch:before {
  content: "\f1e8";
}
.icon-yelp:before {
  content: "\f1e9";
}
.icon-lastfm:before {
  content: "\f202";
}
.icon-odnoklassniki:before {
  content: "\f263";
}
.icon-vimeo:before {
  content: "\f27d";
}
.icon-snapchat-ghost:before {
  content: "\f2ac";
}
.icon-popular:before {
  content: "\e901";
}
.icon-hot:before {
  content: "\e902";
}
.icon-trending3:before {
  content: "\e903";
}
.icon-trending2:before {
  content: "\e904";
}
.icon-trending:before {
  content: "\e905";
}
.icon-bars-cst:before {
  content: "\e900";
}
.icon-search:before {
  content: "\e955";
}
.icon-eye:before {
  content: "\e956";
}

==> boombox-2.0.4-www.persianscript.ir.zip: boombox/amp/fonts/icomoon/style.php <==
<?php
// Root url
$root_url = get_template_directory_uri() . '/amp/';
$icon_fonts_url = $root_url.'fonts/icomoon/fonts/';
?>
/* Note: Please do not forget to remove important styling from font-family: 'icomoon'and keep icon fonts correct url when adding new icons */

@font-face {
  font-family: 'icomoon';
  src:  url('<?php echo $icon_fonts_url;?>icomoon.eot?x04khd');
  src:  url('<?php echo $icon_fonts_url;?>icomoon.eot?x04khd#iefix') format('embedded-opentype'),
    url('<?php echo $icon_fonts_url;?>icomoon.ttf?x04khd') format('truetype'),
    url('<?php echo $icon_fonts_url;?>icomoon.woff?x04khd') format('woff'),
    url('<?php echo $icon_fonts_url;?>icomoon.svg?x04khd#icomoon') format('svg');
  font-weight: normal;
  font-style: normal;
}

[class^="icon-"], [class*=" icon-"] {
  font-family: 'icomoon';
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;

  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

.icon-trending5:before {
  content: "\e906";
}
.icon-popular:before {
  content: "\e901";
}
.icon-hot:before {
  content: "\e902";
}
.icon-trending3:before {
  content: "\e903";
}
.icon-trending2:before {
  content: "\e904";
}
.icon-trending:before {
  content: "\e905";
}
.icon-bars-cst:before {
  content: "\e900";
}
.icon-search:before {
  content: "\e955";
}
.icon-eye:before {
  content: "\e956";
}
.icon-soundcloud:before {
  content: "\f1be";
}
.icon-mixcloud:before {
  content: "\f289";
}
.icon-quora:before {
  content: "\f2c4";
}
.icon-chevron-left:before {
  content: "\f053";
}
.icon-chevron-right:before {
  content: "\f054";
}
.icon-comment-o:before {
  content: "\f0e5";
}
.icon-snapchat:before {
  content: "\f2ab";
}
.icon-snapchat-square:before {
  content: "\f2ad";
}
.icon-globe:before {
  content: "\f0ac";
}
.icon-quote-left:before {
  content: "\f10d";
}
.icon-telegram:before {
  content: "\f2c6";
}
.icon-close:before {
  content: "\f00d";
}
.icon-share:before {
  content: "\f064";
}
.icon-comment:before {
  content: "\f075";
}
.icon-twitter:before {
  content: "\f099";
}
.icon-facebook:before {
  content: "\f09a";
}
.icon-github:before {
  content: "\f09b";
}
.icon-pinterest:before {
  content: "\f0d2";
}
.icon-google-plus:before {
  content: "\f0d5";
}
.icon-caret-down:before {
  content: "\f0d7";
}
.icon-caret-up:before {
  content: "\f0d8";
}
.icon-envelope:before {
  content: "\f0e0";
}
.icon-linkedin:before {
  content: "\f0e1";
}
.icon-youtube:before {
  content: "\f167";
}
.icon-xing:before {
  content: "\f168";
}
.icon-stack-overflow:before {
  content: "\f16c";
}
.icon-instagram:before {
  content: "\f16d";
}
.icon-flickr:before {
  content: "\f16e";
}
.icon-tumblr:before {
  content: "\f173";
}
.icon-dribbble:before {
  content: "\f17d";
}
.icon-foursquare:before {
  content: "\f180";
}
.icon-vk:before {
  content: "\f189";
}
.icon-reddit:before {
  content: "\f1a1";
}
.icon-stumbleupon:before {
  content: "\f1a4";
}
.icon-delicious:before {
  content: "\f1a5";
}
.icon-digg:before {
  content: "\f1a6";
}
.icon-behance:before {
  content: "\f1b4";
}
.icon-deviantart:before {
  content: "\f1bd";
}
.icon-vine:before {
  content: "\f1ca";
}
.icon-codepen:before {
  content: "\f1cb";
}
.icon-jsfiddle:before {
  content: "\f1cc";
}
.icon-slideshare:before {
  content: "\f1e7";
}
.icon-twitch:before {
  content: "\f1e8";
}
.icon-yelp:before {
  content: "\f1e9";
}
.icon-lastfm:before {
  content: "\f202";
}
.icon-odnoklassniki:before {
  content: "\f263";
}
.icon-vimeo:before {
  content: "\f27d";
}
.icon-snapchat-ghost:before {
  content: "\f2ac";
}
